@@ -9,20 +9,24 @@ import pytest
 
 
 def write_configuration(
-    config_path, repository_path, borgmatic_source_directory, postgresql_dump_format='custom'
+    source_directory,
+    config_path,
+    repository_path,
+    borgmatic_source_directory,
+    postgresql_dump_format='custom',
 ):
     '''
     Write out borgmatic configuration into a file at the config path. Set the options so as to work
     for testing. This includes injecting the given repository path, borgmatic source directory for
     storing database dumps, dump format (for PostgreSQL), and encryption passphrase.
     '''
-    config = '''
+    config = f'''
 location:
     source_directories:
-        - {}
+        - {source_directory}
     repositories:
-        - {}
-    borgmatic_source_directory: {}
+        - {repository_path}
+    borgmatic_source_directory: {borgmatic_source_directory}
 
 storage:
     encryption_passphrase: "test"
@@ -33,7 +37,7 @@ hooks:
           hostname: postgresql
           username: postgres
           password: test
-          format: {}
+          format: {postgresql_dump_format}
         - name: all
           hostname: postgresql
           username: postgres
@@ -57,9 +61,7 @@ hooks:
           hostname: mongodb
           username: root
           password: test
-'''.format(
-        config_path, repository_path, borgmatic_source_directory, postgresql_dump_format
-    )
+'''
 
     with open(config_path, 'w') as config_file:
         config_file.write(config)
@@ -71,11 +73,16 @@ def test_database_dump_and_restore():
     repository_path = os.path.join(temporary_directory, 'test.borg')
     borgmatic_source_directory = os.path.join(temporary_directory, '.borgmatic')
 
+    # Write out a special file to ensure that it gets properly excluded and Borg doesn't hang on it.
+    os.mkfifo(os.path.join(temporary_directory, 'special_file'))
+
     original_working_directory = os.getcwd()
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_configuration(config_path, repository_path, borgmatic_source_directory)
+        write_configuration(
+            temporary_directory, config_path, repository_path, borgmatic_source_directory
+        )
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'init', '--encryption', 'repokey']
@@ -114,6 +121,7 @@ def test_database_dump_and_restore_with_directory_format():
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
         write_configuration(
+            temporary_directory,
             config_path,
             repository_path,
             borgmatic_source_directory,
@@ -146,7 +154,9 @@ def test_database_dump_with_error_causes_borgmatic_to_exit():
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_configuration(config_path, repository_path, borgmatic_source_directory)
+        write_configuration(
+            temporary_directory, config_path, repository_path, borgmatic_source_directory
+        )
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'init', '--encryption', 'repokey']
