@@ -9,7 +9,10 @@ from ..test_verbosity import insert_logging_mock
 
 
 def insert_execute_command_mock(command):
-    flexmock(module).should_receive('execute_command').with_args(command).once()
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        command, extra_environment=None
+    ).once()
 
 
 def insert_execute_command_never():
@@ -46,18 +49,6 @@ def test_parse_checks_with_disabled_returns_no_checks():
     assert checks == ()
 
 
-def test_parse_checks_with_data_check_also_injects_archives():
-    checks = module.parse_checks({'checks': [{'name': 'data'}]})
-
-    assert checks == ('data', 'archives')
-
-
-def test_parse_checks_with_data_check_passes_through_archives():
-    checks = module.parse_checks({'checks': [{'name': 'data'}, {'name': 'archives'}]})
-
-    assert checks == ('data', 'archives')
-
-
 def test_parse_checks_prefers_override_checks_to_configured_checks():
     checks = module.parse_checks(
         {'checks': [{'name': 'archives'}]}, only_checks=['repository', 'extract']
@@ -66,12 +57,6 @@ def test_parse_checks_prefers_override_checks_to_configured_checks():
     assert checks == ('repository', 'extract')
 
 
-def test_parse_checks_with_override_data_check_also_injects_archives():
-    checks = module.parse_checks({'checks': [{'name': 'extract'}]}, only_checks=['data'])
-
-    assert checks == ('data', 'archives')
-
-
 @pytest.mark.parametrize(
     'frequency,expected_result',
     (
@@ -203,89 +188,137 @@ def test_filter_checks_on_frequency_restains_check_with_unelapsed_frequency_and_
 
 
 def test_make_check_flags_with_repository_check_returns_flag():
-    flags = module.make_check_flags(('repository',))
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('repository',))
 
     assert flags == ('--repository-only',)
 
 
 def test_make_check_flags_with_archives_check_returns_flag():
-    flags = module.make_check_flags(('archives',))
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('archives',))
 
     assert flags == ('--archives-only',)
 
 
-def test_make_check_flags_with_data_check_returns_flag():
-    flags = module.make_check_flags(('data',))
+def test_make_check_flags_with_data_check_returns_flag_and_implies_archives():
+    flexmock(module.feature).should_receive('available').and_return(True)
 
-    assert flags == ('--verify-data',)
+    flags = module.make_check_flags('1.2.3', ('data',))
+
+    assert flags == ('--archives-only', '--verify-data',)
 
 
 def test_make_check_flags_with_extract_omits_extract_flag():
-    flags = module.make_check_flags(('extract',))
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('extract',))
 
     assert flags == ()
 
 
-def test_make_check_flags_with_default_checks_and_default_prefix_returns_default_flags():
-    flags = module.make_check_flags(('repository', 'archives'), prefix=module.DEFAULT_PREFIX)
+def test_make_check_flags_with_repository_and_data_checks_does_not_return_repository_only():
+    flexmock(module.feature).should_receive('available').and_return(True)
 
-    assert flags == ('--prefix', module.DEFAULT_PREFIX)
+    flags = module.make_check_flags('1.2.3', ('repository', 'data',))
+
+    assert flags == ('--verify-data',)
+
+
+def test_make_check_flags_with_default_checks_and_default_prefix_returns_default_flags():
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags(
+        '1.2.3', ('repository', 'archives'), prefix=module.DEFAULT_PREFIX
+    )
+
+    assert flags == ('--match-archives', f'sh:{module.DEFAULT_PREFIX}*')
 
 
 def test_make_check_flags_with_all_checks_and_default_prefix_returns_default_flags():
+    flexmock(module.feature).should_receive('available').and_return(True)
+
     flags = module.make_check_flags(
-        ('repository', 'archives', 'extract'), prefix=module.DEFAULT_PREFIX
+        '1.2.3', ('repository', 'archives', 'extract'), prefix=module.DEFAULT_PREFIX
     )
 
-    assert flags == ('--prefix', module.DEFAULT_PREFIX)
+    assert flags == ('--match-archives', f'sh:{module.DEFAULT_PREFIX}*')
+
+
+def test_make_check_flags_with_all_checks_and_default_prefix_without_borg_features_returns_glob_archives_flags():
+    flexmock(module.feature).should_receive('available').and_return(False)
+
+    flags = module.make_check_flags(
+        '1.2.3', ('repository', 'archives', 'extract'), prefix=module.DEFAULT_PREFIX
+    )
+
+    assert flags == ('--glob-archives', f'{module.DEFAULT_PREFIX}*')
 
 
 def test_make_check_flags_with_archives_check_and_last_includes_last_flag():
-    flags = module.make_check_flags(('archives',), check_last=3)
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('archives',), check_last=3)
 
     assert flags == ('--archives-only', '--last', '3')
 
 
 def test_make_check_flags_with_repository_check_and_last_omits_last_flag():
-    flags = module.make_check_flags(('repository',), check_last=3)
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('repository',), check_last=3)
 
     assert flags == ('--repository-only',)
 
 
 def test_make_check_flags_with_default_checks_and_last_includes_last_flag():
-    flags = module.make_check_flags(('repository', 'archives'), check_last=3)
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('repository', 'archives'), check_last=3)
 
     assert flags == ('--last', '3')
 
 
-def test_make_check_flags_with_archives_check_and_prefix_includes_prefix_flag():
-    flags = module.make_check_flags(('archives',), prefix='foo-')
+def test_make_check_flags_with_archives_check_and_prefix_includes_match_archives_flag():
+    flexmock(module.feature).should_receive('available').and_return(True)
 
-    assert flags == ('--archives-only', '--prefix', 'foo-')
+    flags = module.make_check_flags('1.2.3', ('archives',), prefix='foo-')
+
+    assert flags == ('--archives-only', '--match-archives', 'sh:foo-*')
 
 
-def test_make_check_flags_with_archives_check_and_empty_prefix_omits_prefix_flag():
-    flags = module.make_check_flags(('archives',), prefix='')
+def test_make_check_flags_with_archives_check_and_empty_prefix_omits_match_archives_flag():
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('archives',), prefix='')
 
     assert flags == ('--archives-only',)
 
 
-def test_make_check_flags_with_archives_check_and_none_prefix_omits_prefix_flag():
-    flags = module.make_check_flags(('archives',), prefix=None)
+def test_make_check_flags_with_archives_check_and_none_prefix_omits_match_archives_flag():
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('archives',), prefix=None)
 
     assert flags == ('--archives-only',)
 
 
-def test_make_check_flags_with_repository_check_and_prefix_omits_prefix_flag():
-    flags = module.make_check_flags(('repository',), prefix='foo-')
+def test_make_check_flags_with_repository_check_and_prefix_omits_match_archives_flag():
+    flexmock(module.feature).should_receive('available').and_return(True)
+
+    flags = module.make_check_flags('1.2.3', ('repository',), prefix='foo-')
 
     assert flags == ('--repository-only',)
 
 
-def test_make_check_flags_with_default_checks_and_prefix_includes_prefix_flag():
-    flags = module.make_check_flags(('repository', 'archives'), prefix='foo-')
+def test_make_check_flags_with_default_checks_and_prefix_includes_match_archives_flag():
+    flexmock(module.feature).should_receive('available').and_return(True)
 
-    assert flags == ('--prefix', 'foo-')
+    flags = module.make_check_flags('1.2.3', ('repository', 'archives'), prefix='foo-')
+
+    assert flags == ('--match-archives', 'sh:foo-*')
 
 
 def test_read_check_time_does_not_raise():
@@ -305,13 +338,17 @@ def test_check_archives_with_progress_calls_borg_with_progress_parameter():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').and_return(())
     flexmock(module).should_receive('execute_command').never()
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+    flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'check', '--progress', 'repo'), output_file=module.DO_NOT_CAPTURE
+        ('borg', 'check', '--progress', 'repo'),
+        output_file=module.DO_NOT_CAPTURE,
+        extra_environment=None,
     ).once()
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -321,6 +358,7 @@ def test_check_archives_with_progress_calls_borg_with_progress_parameter():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
         progress=True,
     )
 
@@ -330,13 +368,17 @@ def test_check_archives_with_repair_calls_borg_with_repair_parameter():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').and_return(())
     flexmock(module).should_receive('execute_command').never()
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+    flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'check', '--repair', 'repo'), output_file=module.DO_NOT_CAPTURE
+        ('borg', 'check', '--repair', 'repo'),
+        output_file=module.DO_NOT_CAPTURE,
+        extra_environment=None,
     ).once()
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -346,6 +388,7 @@ def test_check_archives_with_repair_calls_borg_with_repair_parameter():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
         repair=True,
     )
 
@@ -364,12 +407,13 @@ def test_check_archives_calls_borg_with_parameters(checks):
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').with_args(
-        checks, check_last, module.DEFAULT_PREFIX
+        '1.2.3', checks, check_last, module.DEFAULT_PREFIX
     ).and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'check', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -379,6 +423,7 @@ def test_check_archives_calls_borg_with_parameters(checks):
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -388,7 +433,7 @@ def test_check_archives_with_json_error_raises():
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"unexpected": {"id": "repo"}}'
     )
 
@@ -398,6 +443,7 @@ def test_check_archives_with_json_error_raises():
             location_config={},
             storage_config={},
             consistency_config=consistency_config,
+            local_borg_version='1.2.3',
         )
 
 
@@ -407,7 +453,7 @@ def test_check_archives_with_missing_json_keys_raises():
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return('{invalid JSON')
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return('{invalid JSON')
 
     with pytest.raises(ValueError):
         module.check_archives(
@@ -415,6 +461,7 @@ def test_check_archives_with_missing_json_keys_raises():
             location_config={},
             storage_config={},
             consistency_config=consistency_config,
+            local_borg_version='1.2.3',
         )
 
 
@@ -424,10 +471,11 @@ def test_check_archives_with_extract_check_calls_extract_only():
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').never()
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.extract).should_receive('extract_last_archive_dry_run').once()
     flexmock(module).should_receive('write_check_time')
     insert_execute_command_never()
@@ -437,6 +485,7 @@ def test_check_archives_with_extract_check_calls_extract_only():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -445,10 +494,11 @@ def test_check_archives_with_log_info_calls_borg_with_info_parameter():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_logging_mock(logging.INFO)
     insert_execute_command_mock(('borg', 'check', '--info', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
@@ -459,6 +509,7 @@ def test_check_archives_with_log_info_calls_borg_with_info_parameter():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -467,10 +518,11 @@ def test_check_archives_with_log_debug_calls_borg_with_debug_parameter():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_logging_mock(logging.DEBUG)
     insert_execute_command_mock(('borg', 'check', '--debug', '--show-rc', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
@@ -481,6 +533,7 @@ def test_check_archives_with_log_debug_calls_borg_with_debug_parameter():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -488,7 +541,7 @@ def test_check_archives_without_any_checks_bails():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(())
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     insert_execute_command_never()
@@ -498,6 +551,7 @@ def test_check_archives_without_any_checks_bails():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -507,12 +561,13 @@ def test_check_archives_with_local_path_calls_borg_via_local_path():
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').with_args(
-        checks, check_last, module.DEFAULT_PREFIX
+        '1.2.3', checks, check_last, module.DEFAULT_PREFIX
     ).and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg1', 'check', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -522,6 +577,7 @@ def test_check_archives_with_local_path_calls_borg_via_local_path():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
         local_path='borg1',
     )
 
@@ -532,12 +588,13 @@ def test_check_archives_with_remote_path_calls_borg_with_remote_path_parameters(
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').with_args(
-        checks, check_last, module.DEFAULT_PREFIX
+        '1.2.3', checks, check_last, module.DEFAULT_PREFIX
     ).and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'check', '--remote-path', 'borg1', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -547,6 +604,7 @@ def test_check_archives_with_remote_path_calls_borg_with_remote_path_parameters(
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
         remote_path='borg1',
     )
 
@@ -557,12 +615,13 @@ def test_check_archives_with_lock_wait_calls_borg_with_lock_wait_parameters():
     consistency_config = {'check_last': check_last}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').with_args(
-        checks, check_last, module.DEFAULT_PREFIX
+        '1.2.3', checks, check_last, module.DEFAULT_PREFIX
     ).and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'check', '--lock-wait', '5', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -572,6 +631,7 @@ def test_check_archives_with_lock_wait_calls_borg_with_lock_wait_parameters():
         location_config={},
         storage_config={'lock_wait': 5},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -582,12 +642,13 @@ def test_check_archives_with_retention_prefix():
     consistency_config = {'check_last': check_last, 'prefix': prefix}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').with_args(
-        checks, check_last, prefix
+        '1.2.3', checks, check_last, prefix
     ).and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'check', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -597,6 +658,7 @@ def test_check_archives_with_retention_prefix():
         location_config={},
         storage_config={},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
 
 
@@ -605,10 +667,11 @@ def test_check_archives_with_extra_borg_options_calls_borg_with_extra_options():
     consistency_config = {'check_last': None}
     flexmock(module).should_receive('parse_checks')
     flexmock(module).should_receive('filter_checks_on_frequency').and_return(checks)
-    flexmock(module.info).should_receive('display_archives_info').and_return(
+    flexmock(module.rinfo).should_receive('display_repository_info').and_return(
         '{"repository": {"id": "repo"}}'
     )
     flexmock(module).should_receive('make_check_flags').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'check', '--extra', '--options', 'repo'))
     flexmock(module).should_receive('make_check_time_path')
     flexmock(module).should_receive('write_check_time')
@@ -618,4 +681,5 @@ def test_check_archives_with_extra_borg_options_calls_borg_with_extra_options():
         location_config={},
         storage_config={'extra_borg_options': {'check': '--extra --options'}},
         consistency_config=consistency_config,
+        local_borg_version='1.2.3',
     )
